@@ -88,12 +88,6 @@ fastclime.generator = function(n = 200, d = 50, graph = "random", v = NULL, u =
 		gc()
 	}
 	
-	if(graph == "scale-free"){
-		if(is.null(u)) u = 0.1
-		if(is.null(v)) v = 0.3
-		out = .C("SFGen",dd0=as.integer(2),dd=as.integer(d),G=as.integer(theta),package="fastclime")
-		theta = matrix(as.numeric(out$G),d,d)
-	}
 	diag(theta) = 0
 	omega = theta*v
 	
